#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 warp
version:              3.4.0
visibility:           public
id:                   warp-3.4.0-88S7teaxVGTKO5mHEdGrcO
key:                  warp-3.4.0-88S7teaxVGTKO5mHEdGrcO
license:              MIT
maintainer:           michael@snoyman.com
author:               Michael Snoyman, Kazu Yamamoto, Matt Brown
stability:            Stable
homepage:             http://github.com/yesodweb/wai
synopsis:             A fast, light-weight web server for WAI applications.
description:
    HTTP\/1.0, HTTP\/1.1 and HTTP\/2 are supported.
    For HTTP\/2,  Warp supports direct and ALPN (in TLS)
    but not upgrade.
    API docs and the README are available at
    <http://www.stackage.org/package/warp>.

category:             Web, Yesod
abi:                  cca8d71e061417052df8f5120d085440
exposed:              True
exposed-modules:
    Network.Wai.Handler.Warp Network.Wai.Handler.Warp.Internal

hidden-modules:
    Network.Wai.Handler.Warp.Buffer Network.Wai.Handler.Warp.Conduit
    Network.Wai.Handler.Warp.Counter Network.Wai.Handler.Warp.Date
    Network.Wai.Handler.Warp.FdCache Network.Wai.Handler.Warp.File
    Network.Wai.Handler.Warp.FileInfoCache
    Network.Wai.Handler.Warp.HashMap Network.Wai.Handler.Warp.HTTP1
    Network.Wai.Handler.Warp.HTTP2 Network.Wai.Handler.Warp.HTTP2.File
    Network.Wai.Handler.Warp.HTTP2.PushPromise
    Network.Wai.Handler.Warp.HTTP2.Request
    Network.Wai.Handler.Warp.HTTP2.Response
    Network.Wai.Handler.Warp.HTTP2.Types
    Network.Wai.Handler.Warp.Header Network.Wai.Handler.Warp.IO
    Network.Wai.Handler.Warp.Imports Network.Wai.Handler.Warp.PackInt
    Network.Wai.Handler.Warp.ReadInt Network.Wai.Handler.Warp.Request
    Network.Wai.Handler.Warp.RequestHeader
    Network.Wai.Handler.Warp.Response
    Network.Wai.Handler.Warp.ResponseHeader
    Network.Wai.Handler.Warp.Run Network.Wai.Handler.Warp.SendFile
    Network.Wai.Handler.Warp.Settings Network.Wai.Handler.Warp.Types
    Network.Wai.Handler.Warp.Windows
    Network.Wai.Handler.Warp.WithApplication Paths_warp
    Network.Wai.Handler.Warp.MultiMap

import-dirs:          /usr/lib/ghc-9.6.6/site-local/warp-3.4.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/warp-3.4.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/warp-3.4.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-warp
hs-libraries:         HSwarp-3.4.0-88S7teaxVGTKO5mHEdGrcO
depends:
    array-0.5.6.0 auto-update-0.1.6-BiK7zXEf7x11yi5UX3g5Dn
    base-4.18.2.1 bsb-http-chunked-0.0.0.4-EKxjPKZkEY0JBEkyg5It7v
    bytestring-0.11.5.3 case-insensitive-1.2.1.0-A8CTHJLbf7AArK6CnJHSQw
    containers-0.6.7 crypton-x509-1.7.7-61hDuVrJRCRBiKHXcxYTtj
    ghc-prim-0.10.0 hashable-1.4.7.0-KYRxVQLzygQHnYjqLKyJPN
    http-date-0.0.11-GGzHVleigSSF0OJS6Em1WP
    http-types-0.12.4-FjxwRmZWhoR3wzry1r4T66
    http2-5.1.4-KUux8aw32H29wX9xRkDVfr
    iproute-1.7.15-KfthO9WyCMI6N1Y86uw5VQ
    network-3.1.4.0-9nB9sbnLDjyBVIWLW7TDGb
    recv-0.1.1-JHOpQBMWacCIONlknftyvf
    simple-sendfile-0.2.32-3byPoSwKWtx5VgyRNffGaP stm-2.5.1.0
    streaming-commons-0.2.3.1-MBAvoCiutqJfVNhb5nEzw text-2.0.2
    time-manager-0.0.1-HfH0cwRrILjEPCXi9xo14g unix-2.8.4.0
    unliftio-0.2.25.1-95hsWJFispi2AzgK8xFJw
    vault-0.3.2.0-DEGIC9zoMZ899apZO5fEUf
    wai-3.2.4-E4t208bIe9WGNSF4hxnMlb word8-0.1.3-7y8d2ts6b899pqfTpiB4ap

haddock-interfaces:   /usr/share/doc/haskell-warp/html/warp.haddock
haddock-html:         /usr/share/doc/haskell-warp/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

